==> nextcloud-18.0.8.tgz: nextcloud/apps/password_policy/l10n/it.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La password è scaduta, usa il metodo di password dimenticata per ripristinarla.",
    "Password must not have been used recently before." : "La password non deve essere stata utilizzata recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La password è presente in un elenco di 1.000.000 di password comuni. Rendila unica.",
    "Password is present in compromised password list. Please choose a different password." : "La password è presente in un elenco di password compromesse. Scegli una password diversa.",
    "Password needs to be at least %s characters long" : "La password deve essere composta di almeno %s caratteri",
    "Password needs to contain at least one numeric character." : "La password deve contenere almeno un carattere numerico.",
    "Password needs to contain at least one special character." : "La password deve contenere almeno un carattere speciale.",
    "Password needs to contain at least one lower and one upper case character." : "La password deve contenere almeno un carattere minuscolo e uno maiuscolo.",
    "Password policy" : "Criterio della password",
    "Allows admins to configure a password policy" : "Consente agli amministratori di configurare un criterio per le password",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Consente all'amministratore di definire determinati pre-requisiti per le password, ad es. forzare una lunghezza minima",
    "Minimal length" : "Lunghezza minima",
    "User password history" : "Cronologia della password degli utenti",
    "days until user password expires" : "giorni prima che la password scada",
    "login attempts before the user account is blocked. (0 for no limit)" : "tentativi di accesso prima che l'account utente sia bloccato. (0 per nessun limite)",
    "Forbid common passwords" : "Vieta le password comuni",
    "Enforce upper and lower case characters" : "Forza i caratteri maiuscoli e minuscoli",
    "Enforce numeric characters" : "Forza i caratteri numerici",
    "Enforce special characters" : "Forza i caratteri speciali",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la password con l'elenco di password compromesse di haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Questo controllo crea un hash della password e invia i primi 5 caratteri di questo hash alle API di haveibeenpwned.com per recuperare un elenco di tutti gli hash che iniziano con questi caratteri. Poi controlla se la password dell'istanza Nextcloud è presente nei risultati."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.7.tgz: nextcloud/apps/password_policy/l10n/it.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La password è scaduta, usa il metodo di password dimenticata per ripristinarla.",
    "Password must not have been used recently before." : "La password non deve essere stata utilizzata recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La password è presente in un elenco di 1.000.000 di password comuni. Rendila unica.",
    "Password is present in compromised password list. Please choose a different password." : "La password è presente in un elenco di password compromesse. Scegli una password diversa.",
    "Password needs to be at least %s characters long" : "La password deve essere composta di almeno %s caratteri",
    "Password needs to contain at least one numeric character." : "La password deve contenere almeno un carattere numerico.",
    "Password needs to contain at least one special character." : "La password deve contenere almeno un carattere speciale.",
    "Password needs to contain at least one lower and one upper case character." : "La password deve contenere almeno un carattere minuscolo e uno maiuscolo.",
    "Password policy" : "Criterio della password",
    "Allows admins to configure a password policy" : "Consente agli amministratori di configurare un criterio per le password",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Consente all'amministratore di definire determinati pre-requisiti per le password, ad es. forzare una lunghezza minima",
    "Minimum password length" : "Lunghezza minima della password",
    "User password history" : "Cronologia della password degli utenti",
    "Number of days until user password expires" : "Numero di giorni per la scadenza della password dell'utente",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Numero di tentativi di accesso prima che l'account utente sia bloccato. (0 per nessun limite)",
    "Forbid common passwords" : "Vieta le password comuni",
    "Enforce upper and lower case characters" : "Forza i caratteri maiuscoli e minuscoli",
    "Enforce numeric characters" : "Forza i caratteri numerici",
    "Enforce special characters" : "Forza i caratteri speciali",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la password con l'elenco di password compromesse di haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Questo controllo crea un hash della password e invia i primi 5 caratteri di questo hash alle API di haveibeenpwned.com per recuperare un elenco di tutti gli hash che iniziano con questi caratteri. Poi controlla se la password dell'istanza Nextcloud è presente nei risultati.",
    "Minimal length" : "Lunghezza minima",
    "days until user password expires" : "giorni prima che la password scada",
    "login attempts before the user account is blocked. (0 for no limit)" : "tentativi di accesso prima che l'account utente sia bloccato. (0 per nessun limite)"
},
"nplurals=2; plural=(n != 1);");
